@@ -6,6 +6,7 @@
 ##' These comprise:
 ##' \describe{
 ##' \item{rinit,}{which samples from the distribution of the state process at the zero-time;}
+##' \item{dinit,}{which evaluates the density of the state process at the zero-time;}
 ##' \item{rprocess,}{the simulator of the unobserved Markov state process;}
 ##' \item{dprocess,}{the evaluator of the probability density function for transitions of the unobserved Markov state process;}
 ##' \item{rmeasure,}{the simulator of the observed process, conditional on the unobserved state;}
@@ -24,76 +25,64 @@
 ##' In any case, the effect is the same: to add, remove, or modify the basic component.
 ##'
 ##' Each basic component can be furnished using C snippets, \R functions, or pre-compiled native routine available in user-provided dynamically loaded libraries.
-##'
-##' @name pomp
+##' @name pomp_constructor
+##' @aliases pomp
 ##' @rdname pomp
 ##' @family implementation information
 ##' @include pomp_class.R pomp_fun.R csnippet.R safecall.R builder.R
-##' @include rinit_spec.R rprocess_spec.R rmeasure_spec.R
+##' @include dinit_spec.R rinit_spec.R rprocess_spec.R rmeasure_spec.R
 ##' @include dprocess_spec.R dmeasure_spec.R prior_spec.R
 ##' @include skeleton_spec.R parameter_trans.R covariate_table.R
 ##' @importFrom stats setNames
-##'
 ##' @inheritParams hitch
-##'
 ##' @param data either a data frame holding the time series data,
 ##' or an object of class \sQuote{pomp},
 ##' i.e., the output of another \pkg{pomp} calculation.
-##' Internally, \code{data} will be internally coerced to an array with storage-mode \code{double}.
-##'
+##' Internally, \code{data} will be coerced to an array with storage-mode \code{double}.
 ##' @param times the sequence of observation times.
 ##' \code{times} must indicate the column of observation times by name or index.
 ##' The time vector must be numeric and non-decreasing.
-##'
 ##' @param t0 The zero-time, i.e., the time of the initial state.
 ##' This must be no later than the time of the first observation, i.e., \code{t0 <= times[1]}.
-##'
 ##' @param rinit simulator of the initial-state distribution.
 ##' This can be furnished either as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
 ##' Setting \code{rinit=NULL} sets the initial-state simulator to its default.
-##' For more information, see \link[=rinit specification]{rinit specification}.
-##'
-##' @param rprocess simulator of the latent state process, specified using one of the \link[=rprocess specification]{rprocess plugins}.
+##' For more information, see \link[=rinit_spec]{rinit specification}.
+##' @param dinit evaluator of the initial-state density.
+##' This can be furnished either as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
+##' Setting \code{dinit=NULL} removes this basic component.
+##' For more information, see \link[=dinit_spec]{dinit specification}.
+##' @param rprocess simulator of the latent state process, specified using one of the \link[=rprocess_spec]{rprocess plugins}.
 ##' Setting \code{rprocess=NULL} removes the latent-state simulator.
-##' For more information, see \link[=rprocess specification]{rprocess specification for the documentation on these plugins}.
-##'
-##' @param dprocess optional;
-##' specification of the probability density evaluation function of the unobserved state process.
+##' For more information, see \link[=rprocess_spec]{rprocess specification for the documentation on these plugins}.
+##' @param dprocess evaluator of the probability density of transitions of the unobserved state process.
 ##' Setting \code{dprocess=NULL} removes the latent-state density evaluator.
-##' For more information, see \link[=dprocess specification]{dprocess specification}.
-##'
+##' For more information, see \link[=dprocess_spec]{dprocess specification}.
 ##' @param rmeasure simulator of the measurement model, specified either as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
 ##' Setting \code{rmeasure=NULL} removes the measurement model simulator.
-##' For more information, see \link[=rmeasure specification]{rmeasure specification}.
-##'
+##' For more information, see \link[=rmeasure_spec]{rmeasure specification}.
 ##' @param dmeasure evaluator of the measurement model density, specified either as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
 ##' Setting \code{dmeasure=NULL} removes the measurement density evaluator.
-##' For more information, see \link[=dmeasure specification]{dmeasure specification}.
-##'
+##' For more information, see \link[=dmeasure_spec]{dmeasure specification}.
 ##' @param emeasure the expectation of the measured variables, conditional on the latent state.
 ##' This can be specified as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
 ##' Setting \code{emeasure=NULL} removes the emeasure component.
-##' For more information, see \link[=emeasure specification]{emeasure specification}.
-##'
+##' For more information, see \link[=emeasure_spec]{emeasure specification}.
 ##' @param vmeasure the covariance of the measured variables, conditional on the latent state.
 ##' This can be specified as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
 ##' Setting \code{vmeasure=NULL} removes the vmeasure component.
-##' For more information, see \link[=vmeasure specification]{vmeasure specification}.
-##'
+##' For more information, see \link[=vmeasure_spec]{vmeasure specification}.
 ##' @param skeleton optional; the deterministic skeleton of the unobserved state process.
 ##' Depending on whether the model operates in continuous or discrete time, this is either a vectorfield or a map.
-##' Accordingly, this is supplied using either the \code{\link[=skeleton specification]{vectorfield}} or \code{\link[=skeleton specification]{map}} fnctions.
-##' For more information, see \link[=skeleton specification]{skeleton specification}.
+##' Accordingly, this is supplied using either the \code{\link[=skeleton_spec]{vectorfield}} or \code{\link[=skeleton_spec]{map}} fnctions.
+##' For more information, see \link[=skeleton_spec]{skeleton specification}.
 ##' Setting \code{skeleton=NULL} removes the deterministic skeleton.
-##'
 ##' @param rprior optional; prior distribution sampler, specified either as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
-##' For more information, see \link[=prior specification]{prior specification}.
+##' For more information, see \link[=prior_spec]{prior specification}.
 ##' Setting \code{rprior=NULL} removes the prior distribution sampler.
-##'
 ##' @param dprior optional; prior distribution density evaluator, specified either as a C snippet, an \R function, or the name of a pre-compiled native routine available in a dynamically loaded library.
-##' For more information, see \link[=prior specification]{prior specification}.
+##' For more information, see \link[=prior_spec]{prior specification}.
 ##' Setting \code{dprior=NULL} resets the prior distribution to its default, which is a flat improper prior.
-##'
 ##' @param partrans optional parameter transformations, constructed using \code{\link{parameter_trans}}.
 ##'
 ##' Many algorithms for parameter estimation search an unconstrained space of parameters.
@@ -101,77 +90,67 @@
 ##' One should supply the \code{partrans} argument via a call to \code{\link{parameter_trans}}.
 ##' For more information, see \link[=parameter_trans]{parameter_trans}.
 ##' Setting \code{partrans=NULL} removes the parameter transformations, i.e., sets them to the identity transformation.
-##'
 ##' @param covar optional covariate table, constructed using \code{\link{covariate_table}}.
 ##'
 ##' If a covariate table is supplied, then the value of each of the covariates is interpolated as needed.
 ##' The resulting interpolated values are made available to the appropriate basic components.
 ##' See the documentation for \code{\link{covariate_table}} for details.
-##'
 ##' @param params optional; named numeric vector of parameters.
 ##' This will be coerced internally to storage mode \code{double}.
-##'
 ##' @param obsnames optional character vector;
 ##' names of the observables.
 ##' It is not usually necessary to specify \code{obsnames} since, by default,
 ##' these are read from the names of the data variables.
-##'
 ##' @param statenames optional character vector;
 ##' names of the latent state variables.
 ##' It is typically only necessary to supply \code{statenames} when C snippets are in use.
-##'
+##' See also \code{nstatevars}.
+##' @param nstatevars optional integer scalar;
+##' If C snippets or native routines are used, one can specify the number of state variables with this argument.
+##' By default, \code{nstatevars = length(statenames)}.
 ##' @param paramnames optional character vector;
 ##' names of model parameters.
 ##' It is typically only necessary to supply \code{paramnames} when C snippets are in use.
-##'
 ##' @param covarnames optional character vector;
 ##' names of the covariates.
 ##' It is not usually necessary to specify \code{covarnames} since, by default,
 ##' these are read from the names of the covariates.
-##'
 ##' @param accumvars optional character vector;
 ##' contains the names of accumulator variables.
-##' See \link[=accumulator variables]{accumulators} for a definition and discussion of accumulator variables.
-##'
-##' @param \dots additional arguments supply new or modify existing model characteristics or components.
+##' See \link{accumvars} for a definition and discussion of accumulator variables.
+##' @param ... additional arguments supply new or modify existing model characteristics or components.
 ##' See \code{\link{pomp}} for a full list of recognized arguments.
 ##'
 ##' When named arguments not recognized by \code{\link{pomp}} are provided, these are made available to all basic components via the so-called \dfn{userdata} facility.
 ##' This allows the user to pass information to the basic components outside of the usual routes of covariates (\code{covar}) and model parameters (\code{params}).
 ##' See \link[=userdata]{userdata} for information on how to use this facility.
-##'
 ##' @param verbose logical; if \code{TRUE}, diagnostic messages will be printed to the console.
-##'
 ##' @return
 ##' The \code{pomp} constructor function returns an object, call it \code{P}, of class \sQuote{pomp}.
 ##' \code{P} contains, in addition to the data, any elements of the model that have been specified as arguments to the \code{pomp} constructor function.
 ##' One can add or modify elements of \code{P} by means of further calls to \code{pomp}, using \code{P} as the first argument in such calls.
 ##' One can pass \code{P} to most of the \pkg{pomp} package methods via their \code{data} argument.
-##'
 ##' @section Note:
 ##'
 ##' It is not typically necessary (or indeed feasible) to define all of the basic components for any given purpose.
 ##' However, each \pkg{pomp} algorithm makes use of only a subset of these components.
 ##' When an algorithm requires a basic component that has not been furnished, an error is generated to let you know that you must provide the needed component to use the algorithm.
-##'
 ##' @section Note for Windows users:
-##' 
+##'
 ##' Some Windows users report problems when using C snippets in parallel computations.
 ##' These appear to arise when the temporary files created during the C snippet compilation process are not handled properly by the operating system.
-##' To circumvent this problem, use the \code{\link[=pomp]{cdir}} and \code{\link[=pomp]{cfile}} options to cause the C snippets to be written to a file of your choice, thus avoiding the use of temporary files altogether. 
-##'
+##' To circumvent this problem, use the \code{\link[=pomp]{cdir}} and \code{\link[=pomp]{cfile}} options to cause the C snippets to be written to a file of your choice, thus avoiding the use of temporary files altogether.
 ##' @author Aaron A. King
-##'
 ##' @references
 ##'
 ##' \King2016
-##' 
+##'
 NULL
 
 ##' @rdname pomp
 ##' @export
 pomp <- function (data, times, t0, ...,
-  rinit,
+  rinit, dinit,
   rprocess, dprocess,
   rmeasure, dmeasure, emeasure, vmeasure,
   skeleton,
@@ -179,7 +158,7 @@ pomp <- function (data, times, t0, ...,
   partrans,
   covar, params, accumvars,
   obsnames, statenames, paramnames, covarnames,
-  PACKAGE, globals,
+  nstatevars, PACKAGE, globals, on_load,
   cdir = getOption("pomp_cdir", NULL), cfile,
   shlib.args, compile = TRUE,
   verbose = getOption("verbose", FALSE)) {
@@ -194,11 +173,13 @@ pomp <- function (data, times, t0, ...,
   ## return as quickly as possible if no work is to be done
   if (
     is(data,"pomp") && missing(times) && missing(t0) &&
-      missing(rinit) && missing(rprocess) && missing(dprocess) &&
+      missing(rinit) && missing(dinit) &&
+      missing(rprocess) && missing(dprocess) &&
       missing(rmeasure) && missing(dmeasure) && missing(emeasure) &&
       missing(vmeasure) && missing(skeleton) &&
       missing(rprior) && missing(dprior) && missing(partrans) &&
       missing(covar) && missing(params) && missing(accumvars) &&
+      missing(nstatevars) &&
       ...length() == 0
   )
     return(as(data,"pomp"))
@@ -208,14 +189,16 @@ pomp <- function (data, times, t0, ...,
   tryCatch(
     construct_pomp(
       data=data,times=times,t0=t0,...,
-      rinit=rinit,rprocess=rprocess,dprocess=dprocess,
+      rinit=rinit,dinit=dinit,
+      rprocess=rprocess,dprocess=dprocess,
       rmeasure=rmeasure,dmeasure=dmeasure,
       emeasure=emeasure,vmeasure=vmeasure,
       skeleton=skeleton,rprior=rprior,dprior=dprior,partrans=partrans,
       params=params,covar=covar,accumvars=accumvars,
       obsnames=obsnames,statenames=statenames,paramnames=paramnames,
-      covarnames=covarnames,PACKAGE=PACKAGE,
-      globals=globals,cdir=cdir,cfile=cfile,shlib.args=shlib.args,
+      covarnames=covarnames,nstatevars=nstatevars,PACKAGE=PACKAGE,
+      globals=globals,on_load=on_load,
+      cdir=cdir,cfile=cfile,shlib.args=shlib.args,
       compile=compile,verbose=verbose
     ),
     error = function (e) pStop_(conditionMessage(e))
@@ -302,12 +285,13 @@ setMethod(
   "construct_pomp",
   signature=signature(data="array", times="numeric"),
   definition = function (data, times, ...,
-    rinit, rprocess, dprocess,
+    rinit, dinit, rprocess, dprocess,
     rmeasure, dmeasure, emeasure, vmeasure,
     skeleton, rprior, dprior,
     partrans, params, covar) {
 
     if (missing(rinit)) rinit <- NULL
+    if (missing(dinit)) dinit <- NULL
 
     if (missing(rprocess) || is.null(rprocess)) {
       rprocess <- rproc_plugin()
@@ -339,6 +323,7 @@ setMethod(
       data=data,
       times=times,
       rinit=rinit,
+      dinit=dinit,
       rprocess=rprocess,
       dprocess=dprocess,
       rmeasure=rmeasure,
@@ -370,16 +355,17 @@ setMethod(
   "construct_pomp",
   signature=signature(data="pomp", times="NULL"),
   definition = function (data, times, t0, timename, ...,
-    rinit, rprocess, dprocess,
+    rinit, dinit, rprocess, dprocess,
     rmeasure, dmeasure, emeasure, vmeasure,
-    skeleton, rprior, dprior,
-    partrans, params, covar, accumvars, cfile) {
+    skeleton, rprior, dprior, partrans, params, covar,
+    accumvars, nstatevars, cfile) {
 
     times <- data@times
     if (missing(t0)) t0 <- data@t0
     if (missing(timename)) timename <- data@timename
 
     if (missing(rinit)) rinit <- data@rinit
+    if (missing(dinit)) dinit <- data@dinit
 
     if (missing(rprocess)) rprocess <- data@rprocess
     else if (is.null(rprocess)) rprocess <- rproc_plugin()
@@ -403,6 +389,9 @@ setMethod(
     if (missing(covar)) covar <- data@covar
     if (missing(accumvars)) accumvars <- data@accumvars
 
+    if (missing(nstatevars)) nstatevars <- data@nstatevars
+    else nstatevars <- max(nstatevars[1L],data@nstatevars,na.rm=TRUE)
+
     if (missing(cfile)) cfile <- NULL
     if (!is.null(cfile)) {
       cfile <- as.character(cfile)
@@ -418,6 +407,7 @@ setMethod(
       t0=t0,
       timename=timename,
       rinit=rinit,
+      dinit=dinit,
       rprocess=rprocess,
       dprocess=dprocess,
       rmeasure=rmeasure,
@@ -430,6 +420,7 @@ setMethod(
       partrans=partrans,
       covar=covar,
       accumvars=accumvars,
+      nstatevars=nstatevars,
       params=params,
       .solibs=data@solibs,
       .userdata=data@userdata,
@@ -441,22 +432,24 @@ setMethod(
 )
 
 pomp_internal <- function (data, times, t0, timename, ...,
-  rinit, rprocess, dprocess,
+  rinit, dinit, rprocess, dprocess,
   rmeasure, dmeasure, emeasure, vmeasure,
   skeleton, rprior, dprior,
   partrans, params, covar, accumvars, obsnames, statenames,
-  paramnames, covarnames, PACKAGE, globals, cdir, cfile, shlib.args,
-  compile, .userdata, .solibs = list(), verbose = getOption("verbose", FALSE)) {
+  paramnames, covarnames, nstatevars,
+  PACKAGE, globals, on_load, cdir, cfile, shlib.args,
+  compile, .userdata, .solibs = list(),
+  verbose = getOption("verbose", FALSE)) {
 
   ## check times
   if (missing(times) || !is.numeric(times) || !all(is.finite(times)) ||
-      (length(times)>1 && !all(diff(times)>=0)))
+        (length(times)>1 && !all(diff(times)>=0)))
     pStop_(sQuote("times")," must be a non-decreasing sequence of numbers.")
   storage.mode(times) <- "double"
 
   ## check t0
   if (missing(t0) || !is.numeric(t0) || !is.finite(t0) ||
-      length(t0) > 1 ||  t0 > times[1])
+        length(t0) > 1 ||  t0 > times[1])
     pStop_(sQuote("t0")," must be a single number not greater than ",
       sQuote("times[1]"),".")
   storage.mode(t0) <- "double"
@@ -501,6 +494,10 @@ pomp_internal <- function (data, times, t0, timename, ...,
   if (missing(obsnames)) obsnames <- NULL
   if (missing(covarnames)) covarnames <- NULL
 
+  if (missing(nstatevars)) nstatevars <- 0L
+  nstatevars <- as.integer(nstatevars[1L])
+  nstatevars <- max(nstatevars,length(statenames),na.rm=TRUE)
+
   if (missing(accumvars)) accumvars <- NULL
   accumvars <- unique(as.character(accumvars))
 
@@ -516,7 +513,7 @@ pomp_internal <- function (data, times, t0, timename, ...,
   )
   if (length(params) > 0) {
     if (is.null(names(params)) || !is.numeric(params) ||
-        !all(nzchar(names(params))))
+          !all(nzchar(names(params))))
       pStop_(sQuote("params")," must be a named numeric vector.")
   }
 
@@ -527,17 +524,17 @@ pomp_internal <- function (data, times, t0, timename, ...,
 
   if (is(rmeasure,"Csnippet") && is.null(obsnames)) {
     pStop_("when ",sQuote("rmeasure")," is provided as a C snippet, ",
-           "you must also provide ",sQuote("obsnames"),".")
+      "you must also provide ",sQuote("obsnames"),".")
   }
 
   if (is(emeasure,"Csnippet") && is.null(obsnames)) {
     pStop_("when ",sQuote("emeasure")," is provided as a C snippet, ",
-           "you must also provide ",sQuote("obsnames"),".")
+      "you must also provide ",sQuote("obsnames"),".")
   }
 
   if (is(vmeasure,"Csnippet") && is.null(obsnames)) {
     pStop_("when ",sQuote("vmeasure")," is provided as a C snippet, ",
-           "you must also provide ",sQuote("obsnames"),".")
+      "you must also provide ",sQuote("obsnames"),".")
   }
 
   ## check and arrange covariates
@@ -551,6 +548,7 @@ pomp_internal <- function (data, times, t0, timename, ...,
 
   hitches <- hitch(
     rinit=rinit,
+    dinit=dinit,
     step.fn=rprocess@step.fn,
     rate.fn=rprocess@rate.fn,
     dprocess=dprocess,
@@ -570,6 +568,7 @@ pomp_internal <- function (data, times, t0, timename, ...,
     covarnames=covarnames,
     PACKAGE=PACKAGE,
     globals=globals,
+    on_load=on_load,
     cfile=cfile,
     cdir=cdir,
     shlib.args=shlib.args,
@@ -582,39 +581,41 @@ pomp_internal <- function (data, times, t0, timename, ...,
 
   new(
     "pomp",
-    data = data,
-    times = times,
-    t0 = t0,
-    timename = timename,
-    rinit = hitches$funs$rinit,
-    rprocess = rproc_plugin(
+    data=data,
+    times=times,
+    t0=t0,
+    timename=timename,
+    rinit=hitches$funs$rinit,
+    dinit=hitches$funs$dinit,
+    rprocess=rproc_plugin(
       rprocess,
       step.fn=hitches$funs$step.fn,
       rate.fn=hitches$funs$rate.fn
     ),
-    dprocess = hitches$funs$dprocess,
-    dmeasure = hitches$funs$dmeasure,
-    rmeasure = hitches$funs$rmeasure,
-    emeasure = hitches$funs$emeasure,
-    vmeasure = hitches$funs$vmeasure,
-    skeleton = skel_plugin(
+    dprocess=hitches$funs$dprocess,
+    dmeasure=hitches$funs$dmeasure,
+    rmeasure=hitches$funs$rmeasure,
+    emeasure=hitches$funs$emeasure,
+    vmeasure=hitches$funs$vmeasure,
+    skeleton=skel_plugin(
       skeleton,
       skel.fn=hitches$funs$skeleton
     ),
-    dprior = hitches$funs$dprior,
-    rprior = hitches$funs$rprior,
-    partrans = parameter_trans(
+    dprior=hitches$funs$dprior,
+    rprior=hitches$funs$rprior,
+    partrans=parameter_trans(
       toEst=hitches$funs$toEst,
       fromEst=hitches$funs$fromEst
     ),
-    params = params,
-    covar = covar,
-    accumvars = accumvars,
-    solibs = if (is.null(hitches$lib)) {
-      .solibs
-    } else {
-      c(list(hitches$lib),.solibs)
-    },
-    userdata = .userdata
+    params=params,
+    covar=covar,
+    accumvars=accumvars,
+    nstatevars=nstatevars,
+    solibs=if (is.null(hitches$lib)) {
+             .solibs
+           } else {
+             c(list(hitches$lib),.solibs)
+           },
+    userdata=.userdata
   )
 }
